Installation
============

To install Seagull, run this command in your terminal:

.. code-block:: shell

   pip install pyseagull

This is the preferred method to install Seagull, as it will always install
the most recent stable release.

In case you want to install the bleeding-edge version, clone this repo:

.. code-block:: shell

   git clone https://github.com/ljvmiranda921/seagull.git

and then run

.. code-block:: shell

   cd seagull
   python setup.py install
